@@ -17,6 +17,7 @@
 """Provides conversion functions to generate a CZANN from exported TensorFlow models."""
 import os
 import sys
+from abc import abstractmethod
 from typing import (
     Type,
     Tuple,
@@ -30,7 +31,7 @@ from typing import (
     Generic,
     TypeVar,
 )
-
+from pathlib import Path
 from tensorflow.keras.models import load_model, Model
 
 from czmodel.model_metadata import ModelSpec, ModelMetadata
@@ -40,6 +41,7 @@ from czmodel.legacy_model_metadata import (
 )
 from czmodel.util import keras_export
 from czmodel.util.argument_parsing import dir_file
+from czmodel.util._extract_model import extract_czann_model, extract_czseg_model
 
 if TYPE_CHECKING:
     from tensorflow.keras.layers import Layer
@@ -158,6 +160,22 @@ class BaseConverter(Generic[T, S]):
             postprocessing=postprocessing,
         )
 
+    @abstractmethod
+    def unpack_model(
+        self,
+        model_file: str,
+        target_dir: Path,
+    ) -> Tuple[S, os.PathLike]:
+        """Unpack the model file.
+
+        Args:
+            model_file: Path of the model file
+            target_dir: Target directory for the extraction
+
+        Returns:
+            Tuple containing the model metadata and the model itself in that order
+        """
+
 
 class DefaultConverter(BaseConverter[ModelSpec, ModelMetadata]):
     """Converter for czann models."""
@@ -169,6 +187,23 @@ class DefaultConverter(BaseConverter[ModelSpec, ModelMetadata]):
             conversion_fn=keras_export.DefaultKerasConverter().convert,
         )
 
+    def unpack_model(
+        self,
+        model_file: str,
+        target_dir: Path,
+    ) -> Tuple[ModelMetadata, os.PathLike]:
+        """Unpack the .czann file.
+
+        Args:
+            model_file: Path of the .czann file
+            target_dir: Target directory for the extraction
+
+        Returns:
+            Tuple containing the model metadata and the model itself in that order
+        """
+        model_metadata, model_path = extract_czann_model(model_file, target_dir)
+        return model_metadata, model_path
+
 
 class LegacyConverter(BaseConverter[LegacyModelSpec, LegacyModelMetadata]):
     """Converter for legacy czmodel models."""
@@ -180,6 +215,23 @@ class LegacyConverter(BaseConverter[LegacyModelSpec, LegacyModelMetadata]):
             conversion_fn=keras_export.LegacyKerasConverter().convert,
         )
 
+    def unpack_model(
+        self,
+        model_file: str,
+        target_dir: Path,
+    ) -> Tuple[LegacyModelMetadata, os.PathLike]:
+        """Unpack .czseg or .czmodel file.
+
+        Args:
+            model_file: Path of the .czseg/.czmodel file
+            target_dir: Target directory for the extraction
+
+        Returns:
+            Tuple containing the model metadata and the model itself in that order
+        """
+        model_metadata, model_path = extract_czseg_model(model_file, target_dir)
+        return model_metadata, model_path
+
 
 def parse_args(args: List[str]) -> Any:
     """Parses all arguments from a given collection of system arguments.
